@@ -3,44 +3,51 @@ import tkinter as tk
 import tkinter.ttk as ttk
 import tkinter.tix as tix
 from tkdev.devresize import DevResize
+from tkdev.devicon import Icon_Empty
 from ctypes import windll
 from os import environ
+from win32gui import *
+from win32con import *
+from PySide6.QtCore import Qt
+
 
 windll.user32.SetProcessDPIAware()
 
-GWL_EXSTYLE = -20
-WS_EX_APPWINDOW = 0x00040000
-WS_EX_TOOLWINDOW = 0x00000080
 
-
-def add_taskbar(window):
-    if 'PROGRAMFILES(X86)' in environ:
-        hwnd = windll.user32.GetParent(window.winfo_id())
-        style = windll.user32.GetWindowLongPtrW(hwnd, GWL_EXSTYLE)
-        style = style & ~WS_EX_TOOLWINDOW
-        style = style | WS_EX_APPWINDOW
-        res = windll.user32.SetWindowLongPtrW(hwnd, GWL_EXSTYLE, style)
-        # re-assert the new window style
-    else:
-        hwnd = windll.user32.GetParent(window.winfo_id())
-        style = windll.user32.GetWindowLongW(hwnd, GWL_EXSTYLE)
-        style = style & ~WS_EX_TOOLWINDOW
-        style = style | WS_EX_APPWINDOW
-        res = windll.user32.SetWindowLongW(hwnd, GWL_EXSTYLE, style)
-        # re-assert the new window style
+def window_add_taskbar(window: tk.Tk):
+    hwnd = GetParent(window.winfo_id())
+    style = GetWindowLong(hwnd, GWL_EXSTYLE)
+    style = style & ~WS_EX_TOOLWINDOW
+    style = style | WS_EX_APPWINDOW
+    res = SetWindowLong(hwnd, GWL_EXSTYLE, GetWindowLong(hwnd, GWL_EXSTYLE) & ~WS_EX_TOOLWINDOW | WS_EX_APPWINDOW)
+    # re-assert the new window style
     window.wm_withdraw()
     window.after(10, lambda: window.wm_deiconify())
 
 
+def window_embed(window: tk.Tk, toplevel: tk.Toplevel):
+    def embed():
+        SetParent(GetParent(toplevel.winfo_id()), window.winfo_id())
+        window.attributes("-topmost", False)
+    window.attributes("-topmost", True)
+    window.after(0, embed)
+
+
 def window_centre(window: tk.Tk):
     x = window.winfo_screenwidth() / 2 - window.winfo_width() / 2
     y = window.winfo_screenheight() / 2 - window.winfo_height() / 2
     window.geometry(f"{window.winfo_width()}x{window.winfo_height()}+{round(x)}+{round(y)}")
 
 
-def resize_widget(widget: tk.Widget):
+def window_custom(window: tk.Tk):
+    hwnd = GetParent(window.winfo_id())
+    res = SetWindowLong(hwnd, GWL_STYLE, GetWindowLong(hwnd, GWL_STYLE) & ~WS_CAPTION)
+    window.update()
+
+
+def resize_widget(widget: tk.Widget, size: int = 10):
     try:
-        widget.after(10, lambda: DevResize(widget))
+        widget.after(1, lambda: DevResize(widget, size=size))
     except tk.TclError:
         pass
 
@@ -335,7 +342,7 @@ class DevStatusBar(tk.Frame):
 
 
 class DevSubWindow(tk.Frame):
-    def __init__(self, master, title_label: str = "Title", background="white",
+    def __init__(self, master, title_label: str = "Title", background="white", resize_size: int = 10,
                  button_side=tk.RIGHT,
                  titlebar_background="white",
                  close: bool = True, max: bool = True, min: bool = True, title: bool = True,
@@ -366,7 +373,7 @@ class DevSubWindow(tk.Frame):
                                     close_fg=close_fg, max_fg=max_fg, min_fg=min_fg)
         self.titlebar.pack(fill=tk.X, side=tk.TOP)
         self.bind("Configure", DevResize)
-        resize_widget(self)
+        resize_widget(self, size=resize_size)
         self.update()
 
     def set_titlebar(self, titlebar):
@@ -595,29 +602,49 @@ class DevToast(tk.Toplevel):
 class DevToplevel(tk.Toplevel):
     def __init__(self, master: tk.Tk = None):
         super(DevToplevel, self).__init__(master=master)
-        self.title("tkDev")
-        self.geometry("500x500")
-        self.configure(background="#f0f0f0")
+        self.title("")
+        self.geometry("630x300")
+        self.configure(background="#ffffff")
+        self.iconbitmap(Icon_Empty)
 
-    def wm_statusBar(self, statusBar: tk.Widget):
-        self._statusBar = statusBar
-        self._statusBar.pack(fill=tk.X, side=tk.BOTTOM)
+    def wm_run(self):
+        try:
+            self.mainloop()
+        except tk.TclError:
+            return False
+        else:
+            return True
+
+    run = wm_run
+
+    def wm_statusbar(self, statusBar: tk.Widget = None):
+        if statusBar is None:
+            pass
+        else:
+            self._statusBar = statusBar
+            self._statusBar.pack(fill=tk.X, side=tk.BOTTOM)
         return self._statusBar
 
-    statusbar = wm_statusBar
+    statusbar = wm_statusbar
 
-    def wm_titleBar(self, titleBar: tk.Label, showtask: bool = True):
-        from ctypes import windll
-        self.minsize(100, 30)
-        self.overrideredirect(True)
-        if showtask:
-            self.after(10, lambda: add_taskbar(self))
-        self._titlebar = titleBar
-        self._titlebar.pack(fill=tk.X, side=tk.TOP)
-        DevDrag(self._titlebar, self, True)
+    def wm_titlebar(self, titleBar: tk.Label = None, showtask: bool = True):
+        if titleBar is None:
+            self.minsize(100, 30)
+            self.overrideredirect(True)
+            if showtask:
+                self.after(10, lambda: window_add_taskbar(self))
+        else:
+            self._titlebar = titleBar
+            self._titlebar.pack(fill=tk.X, side=tk.TOP)
+            DevDrag(self._titlebar, self, True)
         return self._titlebar
 
-    titlebar = wm_titleBar
+    titlebar = wm_titlebar
+
+    def wm_menubar(self, menubar: DevMenuBar = None):
+        menubar.show()
+
+    menubar = wm_menubar
 
     def wm_centre(self):
         self.after(1, lambda evt=None: window_centre(self))
@@ -636,31 +663,46 @@ class DevToplevel(tk.Toplevel):
 class DevWindow(tk.Tk):
     def __init__(self):
         super(DevWindow, self).__init__()
-        self.title("tkDev")
-        self.geometry("500x500")
-        self.configure(background="#f0f0f0")
+        self.title("")
+        self.geometry("630x300")
+        self.configure(background="#ffffff")
+        self.iconbitmap(Icon_Empty)
 
-    def wm_statusbar(self, statusBar: tk.Widget):
-        self._statusBar = statusBar
-        self._statusBar.pack(fill=tk.X, side=tk.BOTTOM)
+    def wm_run(self):
+        try:
+            self.mainloop()
+        except tk.TclError:
+            return False
+        else:
+            return True
+
+    run = wm_run
+
+    def wm_statusbar(self, statusBar: tk.Widget = None):
+        if statusBar is None:
+            pass
+        else:
+            self._statusBar = statusBar
+            self._statusBar.pack(fill=tk.X, side=tk.BOTTOM)
         return self._statusBar
 
     statusbar = wm_statusbar
 
-    def wm_titlebar(self, titleBar: tk.Label, showtask: bool = True):
-        from ctypes import windll
-        self.minsize(100, 30)
-        self.overrideredirect(True)
-        if showtask:
-            self.after(10, lambda: add_taskbar(self))
-        self._titlebar = titleBar
-        self._titlebar.pack(fill=tk.X, side=tk.TOP)
-        DevDrag(self._titlebar, self, True)
+    def wm_titlebar(self, titleBar: tk.Label = None, showtask: bool = True):
+        if titleBar is None:
+            self.minsize(100, 30)
+            self.overrideredirect(True)
+            if showtask:
+                self.after(10, lambda: window_add_taskbar(self))
+        else:
+            self._titlebar = titleBar
+            self._titlebar.pack(fill=tk.X, side=tk.TOP)
+            DevDrag(self._titlebar, self, True)
         return self._titlebar
 
     titlebar = wm_titlebar
 
-    def wm_menubar(self, menubar: DevMenuBar):
+    def wm_menubar(self, menubar: DevMenuBar = None):
         menubar.show()
 
     menubar = wm_menubar
@@ -681,5 +723,7 @@ class DevWindow(tk.Tk):
 
 if __name__ == '__main__':
     Root = DevWindow()
+    Top = DevToplevel()
+    window_embed(Root, Top)
     Root.centre()
-    Root.mainloop()
+    Root.run()
